@@ -13,46 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_log import log as logging
-from oslo_serialization import jsonutils as json
-
-from sahara.i18n import _
-from sahara.plugins import exceptions as ex
+from sahara.openstack.common import jsonutils as json
+from sahara.openstack.common import log as logging
+from sahara.plugins.general import exceptions as ex
 from sahara.plugins.hdp.versions import versionhandlerfactory as vhf
 
 
 LOG = logging.getLogger(__name__)
 
 
-def validate_number_of_datanodes(cluster, scaled_groups, default_configs):
-    dfs_replication = 0
-    for config in default_configs:
-        if config.name == 'dfs.replication':
-            dfs_replication = config.default_value
-    conf = cluster.cluster_configs
-    if 'HDFS' in conf and 'dfs.replication' in conf['HDFS']:
-        dfs_replication = conf['HDFS']['dfs.replication']
-
-    if not scaled_groups:
-        scaled_groups = {}
-    dn_count = 0
-    for ng in cluster.node_groups:
-        if 'DATANODE' in ng.node_processes:
-            if ng.id in scaled_groups:
-                dn_count += scaled_groups[ng.id]
-            else:
-                dn_count += ng.count
-
-    if dn_count < int(dfs_replication):
-        raise ex.InvalidComponentCountException(
-            'datanode', _('%s or more') % dfs_replication, dn_count,
-            _('Number of %(dn)s instances should not be less '
-              'than %(replication)s')
-            % {'dn': 'DATANODE', 'replication': 'dfs.replication'})
-
-
-class ClusterSpec(object):
-    def __init__(self, config, version='2.0.6'):
+class ClusterSpec():
+    def __init__(self, config, version='1.3.2'):
         self._config_template = config
         self.services = []
         self.configurations = {}
@@ -139,14 +110,6 @@ class ClusterSpec(object):
 
         return components
 
-    def is_hdfs_ha_enabled(self, cluster):
-        if self.version == '2.0.6':
-            if cluster.cluster_configs.get('HDFSHA', False):
-                if cluster.cluster_configs.HDFSHA.get('hdfs.nnha',
-                                                      False) is True:
-                    return True
-        return False
-
     def _parse_services(self, template_json):
         handler = (vhf.VersionHandlerFactory.get_instance().
                    get_version_handler(self.version))
@@ -187,10 +150,10 @@ class ClusterSpec(object):
         return config_names
 
     def _process_node_groups(self, template_json=None, cluster=None):
-        # get node_groups from config
+    # get node_groups from config
         if template_json and not cluster:
             for group in template_json['host_role_mappings']:
-                node_group = NodeGroup(group['name'])
+                node_group = NodeGroup(group['name'].lower())
                 for component in group['components']:
                     node_group.add_component(component['name'])
                 for host in group['hosts']:
@@ -206,12 +169,16 @@ class ClusterSpec(object):
             self.node_groups = {}
             node_groups = cluster.node_groups
             for ng in node_groups:
-                node_group = NodeGroup(ng.name)
+                node_group = NodeGroup(ng.name.lower())
                 node_group.count = ng.count
                 node_group.id = ng.id
                 node_group.components = ng.node_processes[:]
+                node_group.ng_storage_paths = ng.storage_paths()
                 for instance in ng.instances:
-                    node_group.instances.add(Instance(instance))
+                    node_group.instances.add(Instance(instance.fqdn(),
+                                                      instance.management_ip,
+                                                      instance.internal_ip,
+                                                      instance.remote()))
                 self.node_groups[node_group.name] = node_group
 
     def _determine_deployed_services(self, cluster):
@@ -228,10 +195,6 @@ class ClusterSpec(object):
 
     def _process_user_inputs(self, user_inputs):
         for ui in user_inputs:
-            # if it doesn't have a tag then it's not part of the
-            # operational config that Ambari knows about
-            if not hasattr(ui.config, 'tag'):
-                continue
             user_input_handler = self.user_input_handlers.get(
                 '{0}/{1}'.format(ui.config.tag, ui.config.name),
                 self._default_user_input_handler)
@@ -253,14 +216,14 @@ class ClusterSpec(object):
         config_map[user_input.config.name] = user_input.value
 
 
-class Component(object):
+class Component():
     def __init__(self, name, component_type, cardinality):
         self.name = name
         self.type = component_type
         self.cardinality = cardinality
 
 
-class NodeGroup(object):
+class NodeGroup():
     def __init__(self, name):
         self.id = None
         self.name = name
@@ -269,30 +232,34 @@ class NodeGroup(object):
         self.cardinality = None
         self.count = None
         self.instances = set()
+        self.ng_storage_paths = []
 
     def add_component(self, component):
         self.components.append(component)
 
+    def storage_paths(self):
+        return self.ng_storage_paths
 
-class User(object):
+
+class User():
     def __init__(self, name, password, groups):
         self.name = name
         self.password = password
         self.groups = groups
 
 
-class Instance(object):
-    def __init__(self, sahara_instance):
-        self.inst_fqdn = sahara_instance.fqdn()
-        self.management_ip = sahara_instance.management_ip
-        self.internal_ip = sahara_instance.internal_ip
-        self.sahara_instance = sahara_instance
+class Instance():
+    def __init__(self, fqdn, management_ip, internal_ip, remote):
+        self.inst_fqdn = fqdn
+        self.management_ip = management_ip
+        self.internal_ip = internal_ip
+        self.inst_remote = remote
 
     def fqdn(self):
         return self.inst_fqdn
 
     def remote(self):
-        return self.sahara_instance.remote()
+        return self.inst_remote
 
     def __hash__(self):
         return hash(self.fqdn())
@@ -301,13 +268,13 @@ class Instance(object):
         return self.fqdn() == other.fqdn()
 
 
-class NormalizedClusterConfig(object):
+class NormalizedClusterConfig():
     def __init__(self, cluster_spec):
         self.hadoop_version = cluster_spec.version
         self.cluster_configs = []
         self.node_groups = []
-        self.handler = (vhf.VersionHandlerFactory.get_instance().
-                        get_version_handler(self.hadoop_version))
+        self.handler = vhf.VersionHandlerFactory.get_instance().\
+            get_version_handler(self.hadoop_version)
 
         self._parse_configurations(cluster_spec.configurations)
         self._parse_node_groups(cluster_spec.node_groups)
@@ -318,7 +285,7 @@ class NormalizedClusterConfig(object):
                 target = self._get_property_target(prop)
                 if target:
                     prop_type = self._get_property_type(prop, value)
-                    # TODO(sdpeidel): should we supply a scope?
+                    #todo: should we supply a scope?
                     self.cluster_configs.append(
                         NormalizedConfigEntry(NormalizedConfig(
                             prop, prop_type, value, target, 'cluster'),
@@ -332,14 +299,14 @@ class NormalizedClusterConfig(object):
         return self.handler.get_applicable_target(prop)
 
     def _get_property_type(self, prop, value):
-        # TODO(jspeidel): seems that all numeric prop values in default config
+        #TODO(jspeidel): seems that all numeric prop values in default config
         # are encoded as strings.  This may be incorrect.
-        # TODO(jspeidel): should probably analyze string value to determine if
+        #TODO(jspeidel): should probably analyze string value to determine if
         # it is numeric
-        # TODO(jspeidel): would then need to know whether Ambari expects a
+        #TODO(jspeidel): would then need to know whether Ambari expects a
         # string or a numeric value
         prop_type = type(value).__name__
-        # print 'Type: {0}'.format(prop_type)
+        #print 'Type: {0}'.format(prop_type)
         if prop_type == 'str' or prop_type == 'unicode' or value == '':
             return 'string'
         elif prop_type == 'int':
@@ -348,12 +315,12 @@ class NormalizedClusterConfig(object):
             return 'boolean'
         else:
             raise ValueError(
-                _("Could not determine property type for property "
-                  "'%(property)s' with value: %(value)s") %
-                {"property": prop, "value": value})
+                "Could not determine property type for property '{0}' with "
+                "value: {1}".
+                format(prop, value))
 
 
-class NormalizedConfig(object):
+class NormalizedConfig():
     def __init__(self, name, config_type, default_value, target, scope):
         self.name = name
         self.description = None
@@ -364,18 +331,18 @@ class NormalizedConfig(object):
         self.scope = scope
 
 
-class NormalizedConfigEntry(object):
+class NormalizedConfigEntry():
     def __init__(self, config, value):
         self.config = config
         self.value = value
 
 
-class NormalizedNodeGroup(object):
+class NormalizedNodeGroup():
     def __init__(self, node_group):
         self.name = node_group.name
         self.node_processes = node_group.components
         self.node_configs = None
-        # TODO(jpseidel): should not have to specify img/flavor
+        #TODO(jpseidel): should not have to specify img/flavor
         self.img = None
         # TODO(jmaron) the flavor will be set via an ambari blueprint setting,
         # but that setting doesn't exist yet.  It will be addressed by a bug
