@@ -23,11 +23,11 @@ from sahara.plugins.intel.client import services
 class IntelClient():
     def __init__(self, manager, cluster_name):
         #TODO(alazarev) make credentials configurable (bug #1262881)
-        self.rest = r.RESTClient(manager, 'admin', 'admin', 'v1')
+        self.rest = r.RESTClient(manager, 'admin', 'admin', 'v2')
         self.cluster_name = cluster_name
         self._ctx = self
 
         self.cluster = cluster.Cluster(self)
         self.nodes = nodes.Nodes(self)
-        self.params = params.Params(self, False)
-        self.services = services.Services(self, False)
+        self.params = params.Params(self, True)
+        self.services = services.Services(self, True)
