@@ -133,7 +133,16 @@ def check_flavor_exists(flavor_id):
 
 
 def check_floatingip_pool_exists(ng_name, pool_id):
-    if not nova.get_network(id=pool_id):
+    network = None
+    if CONF.use_neutron:
+        network = nova.get_network(id=pool_id)
+    else:
+        for net in nova.client().floating_ip_pools.list():
+            if net.name == pool_id:
+                network = net.name
+                break
+
+    if not network:
         raise ex.InvalidException("Floating IP pool %s for node group "
                                   "'%s' not found" % (pool_id, ng_name))
 
@@ -312,9 +321,6 @@ def check_required_image_tags(plugin_name, hadoop_version, image_id):
 ## EDP
 
 
-def check_cluster_contains_oozie(cluster_id):
+def check_edp_job_support(cluster_id):
     cluster = api.get_cluster(cluster_id)
-    if not plugin_base.PLUGINS.get_plugin(
-            cluster.plugin_name).get_oozie_server(cluster):
-        raise ex.InvalidDataException('MapReduce job could not be run, '
-                                      'Oozie service is not found.')
+    plugin_base.PLUGINS.get_plugin(cluster.plugin_name).validate_edp(cluster)
