@@ -30,12 +30,11 @@ HADOOP_SWIFT_USERNAME = 'fs.swift.service.sahara.username'
 HADOOP_SWIFT_PASSWORD = 'fs.swift.service.sahara.password'
 
 
-def _retrieve_tenant():
+def retrieve_tenant():
     try:
         return context.current().tenant_name
     except RuntimeError:
-        LOG.exception("Cannot retrieve tenant for swift integration. "
-                      "Stopping cluster creation")
+        LOG.exception("Cannot retrieve tenant for swift integration.")
         #todo(slukjanov?) raise special error here
         raise RuntimeError("Cannot retrieve tenant for swift integration")
 
@@ -46,7 +45,7 @@ def get_swift_configs():
         if conf['name'] == HADOOP_SWIFT_AUTH_URL:
             conf['value'] = su.retrieve_auth_url() + "tokens/"
         if conf['name'] == HADOOP_SWIFT_TENANT:
-            conf['value'] = _retrieve_tenant()
+            conf['value'] = retrieve_tenant()
 
     result = [cfg for cfg in configs if cfg['value']]
     LOG.info("Swift would be integrated with the following "
