@@ -14,21 +14,21 @@
 # limitations under the License.
 
 import mock
+import unittest2
 
 from sahara import exceptions as e
-from sahara.plugins import exceptions as ex
+from sahara.plugins.general import exceptions as ex
 from sahara.plugins.hdp.versions import versionhandlerfactory as vhf
-from sahara.tests.unit import base
 from sahara.tests.unit.plugins.hdp import hdp_test_base
 
-versions = ['2.0.6']
+versions = ['1.3.2', '2.0.6']
 
 
-class ServicesTest(base.SaharaTestCase):
-    # TODO(jspeidel): test remaining service functionality which isn't
+class ServicesTest(unittest2.TestCase):
+    #TODO(jspeidel): test remaining service functionality which isn't
     # tested by coarser grained unit tests.
 
-    def get_services_processor(self, version='2.0.6'):
+    def get_services_processor(self, version='1.3.2'):
         handler = (vhf.VersionHandlerFactory.get_instance().
                    get_version_handler(version))
         s = handler.get_services_processor()
@@ -44,6 +44,29 @@ class ServicesTest(base.SaharaTestCase):
                              expected_configs & service.configurations)
             self.assertTrue(service.is_mandatory())
 
+    def test_hdfs_service_register_urls(self):
+        s = self.get_services_processor()
+        service = s.create_service('HDFS')
+        cluster_spec = mock.Mock()
+        cluster_spec.configurations = {
+            'core-site': {
+                'fs.default.name': 'hdfs://not_expected.com:9020'
+            },
+            'hdfs-site': {
+                'dfs.http.address': 'http://not_expected.com:10070'
+            }
+        }
+        instance_mock = mock.Mock()
+        instance_mock.management_ip = '127.0.0.1'
+        cluster_spec.determine_component_hosts = mock.Mock(
+            return_value=[instance_mock])
+        url_info = {}
+        url_info = service.register_service_urls(cluster_spec, url_info)
+        self.assertEqual(url_info['HDFS']['Web UI'],
+                         'http://127.0.0.1:10070')
+        self.assertEqual(url_info['HDFS']['NameNode'],
+                         'hdfs://127.0.0.1:9020')
+
     def test_hdp2_hdfs_service_register_urls(self):
         s = self.get_services_processor('2.0.6')
         service = s.create_service('HDFS')
@@ -60,42 +83,21 @@ class ServicesTest(base.SaharaTestCase):
         instance_mock.management_ip = '127.0.0.1'
         cluster_spec.determine_component_hosts = mock.Mock(
             return_value=[instance_mock])
-        cluster = mock.Mock(cluster_configs={}, name="hdp")
         url_info = {}
-        url_info = service.register_service_urls(cluster_spec, url_info,
-                                                 cluster)
+        url_info = service.register_service_urls(cluster_spec, url_info)
         self.assertEqual(url_info['HDFS']['Web UI'],
                          'http://127.0.0.1:10070')
         self.assertEqual(url_info['HDFS']['NameNode'],
                          'hdfs://127.0.0.1:9020')
 
-    def test_hdp2_ha_hdfs_service_register_urls(self):
-        s = self.get_services_processor('2.0.6')
-        service = s.create_service('HDFS')
-        cluster_spec = mock.Mock()
-        cluster_spec.configurations = {
-            'core-site': {
-                'fs.defaultFS': 'hdfs://not_expected.com:9020'
-            },
-            'hdfs-site': {
-                'dfs.namenode.http-address': 'http://not_expected.com:10070'
-            }
-        }
-        instance_mock = mock.Mock()
-        instance_mock.management_ip = '127.0.0.1'
-        cluster_spec.determine_component_hosts = mock.Mock(
-            return_value=[instance_mock])
-        cluster = mock.Mock(cluster_configs={'HDFSHA': {'hdfs.nnha': True}})
-        cluster.name = "hdp-cluster"
-        url_info = {}
-        url_info = service.register_service_urls(cluster_spec, url_info,
-                                                 cluster)
-        self.assertEqual(url_info['HDFS']['Web UI'],
-                         'http://127.0.0.1:10070')
-        self.assertEqual(url_info['HDFS']['NameNode'],
-                         'hdfs://127.0.0.1:9020')
-        self.assertEqual(url_info['HDFS']['NameService'],
-                         'hdfs://hdp-cluster')
+    def test_create_mr_service(self):
+        s = self.get_services_processor()
+        service = s.create_service('MAPREDUCE')
+        self.assertEqual('MAPREDUCE', service.name)
+        expected_configs = set(['global', 'core-site', 'mapred-site'])
+        self.assertEqual(expected_configs,
+                         expected_configs & service.configurations)
+        self.assertTrue(service.is_mandatory())
 
     def test_create_mr2_service(self):
         s = self.get_services_processor('2.0.6')
@@ -106,6 +108,28 @@ class ServicesTest(base.SaharaTestCase):
                          expected_configs & service.configurations)
         self.assertTrue(service.is_mandatory())
 
+    def test_mr_service_register_urls(self):
+        s = self.get_services_processor()
+        service = s.create_service('MAPREDUCE')
+        cluster_spec = mock.Mock()
+        cluster_spec.configurations = {
+            'mapred-site': {
+                'mapred.job.tracker': 'hdfs://not_expected.com:10300',
+                'mapred.job.tracker.http.address':
+                'http://not_expected.com:10030'
+            }
+        }
+        instance_mock = mock.Mock()
+        instance_mock.management_ip = '127.0.0.1'
+        cluster_spec.determine_component_hosts = mock.Mock(
+            return_value=[instance_mock])
+        url_info = {}
+        url_info = service.register_service_urls(cluster_spec, url_info)
+        self.assertEqual(url_info['MapReduce']['Web UI'],
+                         'http://127.0.0.1:10030')
+        self.assertEqual(url_info['MapReduce']['JobTracker'],
+                         '127.0.0.1:10300')
+
     def test_hdp2_mr2_service_register_urls(self):
         s = self.get_services_processor('2.0.6')
         service = s.create_service('MAPREDUCE2')
@@ -123,8 +147,7 @@ class ServicesTest(base.SaharaTestCase):
         cluster_spec.determine_component_hosts = mock.Mock(
             return_value=[instance_mock])
         url_info = {}
-        url_info = service.register_service_urls(cluster_spec, url_info,
-                                                 mock.Mock())
+        url_info = service.register_service_urls(cluster_spec, url_info)
         self.assertEqual(url_info['MapReduce2']['Web UI'],
                          'http://127.0.0.1:10030')
         self.assertEqual(url_info['MapReduce2']['History Server'],
@@ -158,7 +181,7 @@ class ServicesTest(base.SaharaTestCase):
             expected_configs = set(['global', 'core-site'])
             self.assertEqual(expected_configs,
                              expected_configs & service.configurations)
-            self.assertTrue(service.is_mandatory())
+            self.assertFalse(service.is_mandatory())
 
     def test_create_oozie_service(self):
         for version in versions:
@@ -185,10 +208,9 @@ class ServicesTest(base.SaharaTestCase):
             cluster_spec.determine_component_hosts = mock.Mock(
                 return_value=[instance_mock])
             url_info = {}
-            url_info = service.register_service_urls(cluster_spec, url_info,
-                                                     mock.Mock())
-            self.assertEqual('http://127.0.0.1:21000',
-                             url_info['JobFlow']['Oozie'])
+            url_info = service.register_service_urls(cluster_spec, url_info)
+            self.assertEqual(url_info['JobFlow']['Oozie'],
+                             'http://127.0.0.1:21000')
 
     def test_create_ganglia_service(self):
         for version in versions:
@@ -210,6 +232,43 @@ class ServicesTest(base.SaharaTestCase):
                              expected_configs & service.configurations)
             self.assertTrue(service.is_mandatory())
 
+    @mock.patch("sahara.utils.openstack.nova.get_instance_info",
+                hdp_test_base.get_instance_info)
+    @mock.patch(
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
+        '_get_swift_properties',
+        return_value=[])
+    def test_create_sqoop_service(self, patched):
+        s = self.get_services_processor()
+        service = s.create_service('SQOOP')
+        self.assertEqual('SQOOP', service.name)
+        expected_configs = set(['global', 'core-site'])
+        self.assertEqual(expected_configs,
+                         expected_configs & service.configurations)
+        self.assertFalse(service.is_mandatory())
+
+        # ensure that hdfs and mr clients are added implicitly
+        master_host = hdp_test_base.TestServer(
+            'master.novalocal', 'master', '11111', 3,
+            '111.11.1111', '222.11.1111')
+        master_ng = hdp_test_base.TestNodeGroup(
+            'master', [master_host], ["NAMENODE", "JOBTRACKER",
+            "SECONDARY_NAMENODE", "TASKTRACKER", "DATANODE", "AMBARI_SERVER"])
+        sqoop_host = hdp_test_base.TestServer(
+            'sqoop.novalocal', 'sqoop', '11111', 3,
+            '111.11.1111', '222.11.1111')
+        sqoop_ng = hdp_test_base.TestNodeGroup(
+            'sqoop', [sqoop_host], ["SQOOP"])
+        cluster = hdp_test_base.TestCluster([master_ng, sqoop_ng])
+
+        cluster_spec = hdp_test_base.create_clusterspec()
+        cluster_spec.create_operational_config(cluster, [])
+
+        components = cluster_spec.get_node_groups_containing_component(
+            'SQOOP')[0].components
+        self.assertIn('HDFS_CLIENT', components)
+        self.assertIn('MAPREDUCE_CLIENT', components)
+
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
     @mock.patch(
@@ -252,7 +311,7 @@ class ServicesTest(base.SaharaTestCase):
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
     @mock.patch(
-        'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
     def test_create_hbase_service(self, patched):
@@ -275,11 +334,15 @@ class ServicesTest(base.SaharaTestCase):
 
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
+    @mock.patch(
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
+        '_get_swift_properties',
+        return_value=[])
     @mock.patch(
         'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
-    def test_create_hdp2_hbase_service(self, patched):
+    def test_create_hdp2_hbase_service(self, patched2, patched):
         for version in versions:
             s = self.get_services_processor(version=version)
             service = s.create_service('HBASE')
@@ -289,7 +352,7 @@ class ServicesTest(base.SaharaTestCase):
                              expected_configs & service.configurations)
             self.assertFalse(service.is_mandatory())
 
-            cluster = self._create_hbase_cluster()
+            cluster = self._create_hbase_cluster(version=version)
 
             cluster_spec = hdp_test_base.create_clusterspec(
                 hdp_version=version)
@@ -310,13 +373,17 @@ class ServicesTest(base.SaharaTestCase):
 
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
+    @mock.patch(
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
+        '_get_swift_properties',
+        return_value=[])
     @mock.patch(
         'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
-    def test_hbase_properties(self, patched):
+    def test_hbase_properties(self, patched2, patched):
         for version in versions:
-            cluster = self._create_hbase_cluster()
+            cluster = self._create_hbase_cluster(version=version)
 
             cluster_spec = hdp_test_base.create_clusterspec(
                 hdp_version=version)
@@ -371,11 +438,11 @@ class ServicesTest(base.SaharaTestCase):
             self.assertEqual(
                 "111",
                 cluster_spec.configurations['hbase-site'][
-                    'hbase.regionserver.global.memstore.upperLimit'])
+                'hbase.regionserver.global.memstore.upperLimit'])
             self.assertEqual(
                 "111",
                 cluster_spec.configurations['global'][
-                    'regionserver_memstore_upperlimit'])
+                'regionserver_memstore_upperlimit'])
             ui_handlers[
                 'hbase-site/hbase.hstore.blockingStoreFiles'](
                     hdp_test_base.TestUserInput(
@@ -557,7 +624,7 @@ class ServicesTest(base.SaharaTestCase):
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
     @mock.patch(
-        'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
     def test_hbase_validation(self, patched):
@@ -565,14 +632,10 @@ class ServicesTest(base.SaharaTestCase):
             'master.novalocal', 'master', '11111', 3,
             '111.11.1111', '222.11.1111')
         master_ng = hdp_test_base.TestNodeGroup(
-            'master', [master_host], ["NAMENODE",
-                                      'RESOURCEMANAGER', 'YARN_CLIENT',
-                                      'NODEMANAGER',
+            'master', [master_host], ["NAMENODE", "JOBTRACKER",
                                       "SECONDARY_NAMENODE",
-                                      "DATANODE",
-                                      "AMBARI_SERVER",
-                                      'HISTORYSERVER', 'MAPREDUCE2_CLIENT',
-                                      'ZOOKEEPER_SERVER', 'ZOOKEEPER_CLIENT'])
+                                      "TASKTRACKER", "DATANODE",
+                                      "AMBARI_SERVER"])
         hbase_host = hdp_test_base.TestServer(
             'hbase.novalocal', 'hbase', '11111', 3,
             '111.11.1111', '222.11.1111')
@@ -706,13 +769,17 @@ class ServicesTest(base.SaharaTestCase):
 
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
+    @mock.patch(
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
+        '_get_swift_properties',
+        return_value=[])
     @mock.patch(
         'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
-    def test_hbase_service_urls(self, patched):
+    def test_hbase_service_urls(self, patched2, patched):
         for version in versions:
-            cluster = self._create_hbase_cluster()
+            cluster = self._create_hbase_cluster(version=version)
             cluster_spec = hdp_test_base.create_clusterspec(
                 hdp_version=version)
             cluster_spec.create_operational_config(cluster, [])
@@ -720,7 +787,7 @@ class ServicesTest(base.SaharaTestCase):
             service = s.create_service('HBASE')
 
             url_info = {}
-            service.register_service_urls(cluster_spec, url_info, mock.Mock())
+            service.register_service_urls(cluster_spec, url_info)
             self.assertEqual(1, len(url_info))
             self.assertEqual(6, len(url_info['HBase']))
             self.assertEqual('http://222.22.2222:60010/master-status',
@@ -738,13 +805,17 @@ class ServicesTest(base.SaharaTestCase):
 
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 hdp_test_base.get_instance_info)
+    @mock.patch(
+        'sahara.plugins.hdp.versions.version_1_3_2.services.HdfsService.'
+        '_get_swift_properties',
+        return_value=[])
     @mock.patch(
         'sahara.plugins.hdp.versions.version_2_0_6.services.HdfsService.'
         '_get_swift_properties',
         return_value=[])
-    def test_hbase_replace_tokens(self, patched):
+    def test_hbase_replace_tokens(self, patched2, patched):
         for version in versions:
-            cluster = self._create_hbase_cluster()
+            cluster = self._create_hbase_cluster(version=version)
             cluster_spec = hdp_test_base.create_clusterspec(
                 hdp_version=version)
             cluster_spec.create_operational_config(cluster, [])
@@ -754,62 +825,57 @@ class ServicesTest(base.SaharaTestCase):
 
             self.assertEqual("hdfs://master.novalocal:8020/apps/hbase/data",
                              cluster_spec.configurations['hbase-site'][
-                                 'hbase.rootdir'])
-            self.assertEqual(set(['zk.novalocal', 'master.novalocal']),
-                             set(cluster_spec.configurations['hbase-site'][
-                                 'hbase.zookeeper.quorum'].split(',')))
+                             'hbase.rootdir'])
+            self.assertEqual("master.novalocal",
+                             cluster_spec.configurations['hbase-site'][
+                             'hbase.zookeeper.quorum'])
 
     def test_get_storage_paths(self):
         for version in versions:
             s = self.get_services_processor(version=version)
             service = s.create_service('AMBARI')
-            server1 = hdp_test_base.TestServer(
-                'host1', 'test-master', '11111', 3, '1.1.1.1', '2.2.2.2')
-            server2 = hdp_test_base.TestServer(
-                'host2', 'test-slave', '11111', 3, '3.3.3.3', '4.4.4.4')
-            server3 = hdp_test_base.TestServer(
-                'host3', 'another-test', '11111', 3, '6.6.6.6', '5.5.5.5')
-            ng1 = hdp_test_base.TestNodeGroup('ng1', [server1], None)
-            ng2 = hdp_test_base.TestNodeGroup('ng2', [server2], None)
-            ng3 = hdp_test_base.TestNodeGroup('ng3', [server3], None)
-
-            server1.storage_path = ['/volume/disk1']
-            server2.storage_path = ['/mnt']
+            ng1 = hdp_test_base.TestNodeGroup(None, None, None)
+            ng1.ng_storage_paths = ['/mnt', '/volume/disk1']
+            ng2 = hdp_test_base.TestNodeGroup(None, None, None)
+            ng2.ng_storage_paths = ['/mnt']
 
             paths = service._get_common_paths([ng1, ng2])
-            self.assertEqual([], paths)
+            self.assertEqual(['/mnt'], paths)
 
-            server1.storage_path = ['/volume/disk1', '/volume/disk2']
-            server2.storage_path = ['/mnt']
-            server3.storage_path = ['/volume/disk1']
+            ng3 = hdp_test_base.TestNodeGroup(None, None, None)
+            ng1.ng_storage_paths = ['/mnt', '/volume/disk1', '/volume/disk2']
+            ng2.ng_storage_paths = ['/mnt']
+            ng3.ng_storage_paths = ['/mnt', '/volume/disk1']
 
             paths = service._get_common_paths([ng1, ng2, ng3])
-            self.assertEqual([], paths)
+            self.assertEqual(['/mnt'], paths)
 
-            server1.storage_path = ['/volume/disk1', '/volume/disk2']
-            server2.storage_path = ['/volume/disk1']
-            server3.storage_path = ['/volume/disk1']
+            ng1.ng_storage_paths = ['/mnt', '/volume/disk1', '/volume/disk2']
+            ng2.ng_storage_paths = ['/mnt', '/volume/disk1']
+            ng3.ng_storage_paths = ['/mnt', '/volume/disk1']
 
             paths = service._get_common_paths([ng1, ng2, ng3])
             self.assertEqual(['/volume/disk1'], paths)
 
-    def _create_hbase_cluster(self):
+    def _create_hbase_cluster(self, version='1.3.2'):
         master_host = hdp_test_base.TestServer(
             'master.novalocal', 'master', '11111', 3,
             '111.11.1111', '222.11.1111')
-        master_ng = hdp_test_base.TestNodeGroup(
-            'master', [master_host], ["NAMENODE", "RESOURCEMANAGER",
-                                      "SECONDARY_NAMENODE", "NODEMANAGER",
-                                      "DATANODE", "AMBARI_SERVER",
-                                      "HISTORYSERVER", "ZOOKEEPER_SERVER"])
-        extra_zk_host = hdp_test_base.TestServer(
-            'zk.novalocal', 'zk', '11112', 3,
-            '111.11.1112', '222.11.1112')
-        extra_zk_ng = hdp_test_base.TestNodeGroup(
-            'zk', [extra_zk_host], ['ZOOKEEPER_SERVER'])
+        if version == '1.3.2':
+            master_ng = hdp_test_base.TestNodeGroup(
+                'master', [master_host], ["NAMENODE", "JOBTRACKER",
+                                          "SECONDARY_NAMENODE", "TASKTRACKER",
+                                          "DATANODE", "AMBARI_SERVER",
+                                          "ZOOKEEPER_SERVER"])
+        elif version == '2.0.6':
+            master_ng = hdp_test_base.TestNodeGroup(
+                'master', [master_host], ["NAMENODE", "RESOURCEMANAGER",
+                                          "SECONDARY_NAMENODE", "NODEMANAGER",
+                                          "DATANODE", "AMBARI_SERVER",
+                                          "HISTORYSERVER", "ZOOKEEPER_SERVER"])
         hbase_host = hdp_test_base.TestServer(
             'hbase.novalocal', 'hbase', '11111', 3,
             '222.22.2222', '222.11.1111')
         hbase_ng = hdp_test_base.TestNodeGroup(
             'hbase', [hbase_host], ["HBASE_MASTER"])
-        return hdp_test_base.TestCluster([master_ng, extra_zk_ng, hbase_ng])
+        return hdp_test_base.TestCluster([master_ng, hbase_ng])
