@@ -13,19 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
-
 from sahara.service import api
-from sahara.service.validations import node_group_template_schema as ngt_schema
 from sahara.service.validations import node_group_templates as nt
 from sahara.tests.unit.service.validation import utils as u
 
 
 class TestNGTemplateCreateValidation(u.ValidationTestCase):
     def setUp(self):
-        super(TestNGTemplateCreateValidation, self).setUp()
         self._create_object_fun = nt.check_node_group_template_create
-        self.scheme = ngt_schema.NODE_GROUP_TEMPLATE_SCHEMA
+        self.scheme = nt.NODE_GROUP_TEMPLATE_SCHEMA
         api.plugin_base.setup_plugins()
 
     def test_node_groups_create_required(self):
@@ -46,7 +42,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
+                'plugin_name': 'vanilla',
             },
             bad_req_i=(1, "VALIDATION_ERROR",
                        u"'hadoop_version' is a required property")
@@ -55,8 +51,8 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1'
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1'
             },
             bad_req_i=(1, "VALIDATION_ERROR",
                        u"'node_processes' is a required property")
@@ -65,20 +61,20 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': "a",
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': []
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'\[\] is too short')
+                       u'[] is too short')
         )
 
     def test_ng_template_create_v_names(self):
         data = {
             'name': 'a',
             'flavor_id': '42',
-            'plugin_name': 'fake',
-            'hadoop_version': '0.1',
+            'plugin_name': 'vanilla',
+            'hadoop_version': '1.2.1',
             'node_processes': ['namenode']
         }
         self._assert_valid_name_hostname_validation(data)
@@ -88,90 +84,49 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': "a",
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ["namenode", "namenode"]
             },
-            bad_req_i=(1, 'INVALID_DATA',
+            bad_req_i=(1, 'INVALID_REFERENCE',
                        'Duplicates in node processes have been detected')
         )
         self._assert_create_object_validation(
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['wrong_process']
             },
             bad_req_i=(1, 'INVALID_REFERENCE',
-                       "Plugin doesn't support the following node processes: "
-                       "['wrong_process']")
+                       "Plugin supports the following node procesess: "
+                       "['namenode', 'datanode', 'secondarynamenode', "
+                       "'oozie', 'tasktracker', 'jobtracker', 'hiveserver']")
         )
 
-    @mock.patch(
-        "sahara.service.validations.base.check_volume_availability_zone_exist")
-    @mock.patch("sahara.service.validations.base.check_volume_type_exists")
-    @mock.patch(
-        "sahara.service.validations.base.check_availability_zone_exist")
-    @mock.patch("sahara.service.validations.base.check_security_groups_exist")
-    def test_ng_template_create_v_right(self,
-                                        s_groups, a_zone, v_type, v_a_zone):
+    def test_ng_template_create_v_right(self):
         self._assert_create_object_validation(
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['namenode',
                                    'datanode',
+                                   'secondarynamenode',
                                    'tasktracker',
                                    'jobtracker'],
+                'node_configs': {
+                    'HDFS': {
+                        u'hadoop.tmp.dir': '/temp/'
+                    }
+                },
                 'image_id': '550e8400-e29b-41d4-a716-446655440000',
-                'node_configs': {},
                 'volumes_per_node': 2,
                 'volumes_size': 10,
-                'volume_type': 'fish',
-                'volumes_availability_zone': 'ocean',
-                'volume_mount_prefix': '/tmp',
-                'description': "my node group",
-                'floating_ip_pool': 'd9a3bebc-f788-4b81-9a93-aa048022c1ca',
-                'security_groups': ['cat', 'dog'],
-                'auto_security_group': False,
-                'availability_zone': 'here',
-                'is_proxy_gateway': False,
-                'volume_local_to_instance': False,
-                'is_public': False,
-                'is_protected': False
-            }
-        )
-
-    def test_ng_template_create_v_nulls(self):
-        self._assert_create_object_validation(
-            data={
-                'name': 'a',
-                'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
-                'node_processes': ['namenode',
-                                   'datanode',
-                                   'tasktracker',
-                                   'jobtracker'],
-
-                'image_id': None,
-                'node_configs': None,
-                'volumes_size': None,
-                'volume_type': None,
-                'volumes_availability_zone': None,
-                'volume_mount_prefix': None,
-                'description': None,
-                'floating_ip_pool': None,
-                'security_groups': None,
-                'auto_security_group': None,
-                'availability_zone': None,
-                'is_proxy_gateway': None,
-                'volume_local_to_instance': None,
-                'is_public': None,
-                'is_protected': None
+                'description': 'test node template',
+                'floating_ip_pool': 'd9a3bebc-f788-4b81-9a93-aa048022c1ca'
             }
         )
 
@@ -180,32 +135,32 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['wrong_process'],
                 'volumes_per_node': -1
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'-1(.0)? is less than the minimum of 0')
+                       u'-1.0 is less than the minimum of 0')
         )
         self._assert_create_object_validation(
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['wrong_process'],
                 'volumes_size': 0
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'0(.0)? is less than the minimum of 1')
+                       u'0.0 is less than the minimum of 1')
         )
 
     def test_ng_template_create_v_types(self):
         default_data = {
             'name': 'a', 'flavor_id': '42',
-            'plugin_name': 'fake',
-            'hadoop_version': '0.1',
+            'plugin_name': 'vanilla',
+            'hadoop_version': '1.2.1',
             'node_processes': ['namenode']
         }
         self._assert_types(default_data)
@@ -214,8 +169,8 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
         data = {
             'name': 'test',
             'flavor_id': '42',
-            'plugin_name': 'fake',
-            'hadoop_version': '0.1',
+            'plugin_name': 'vanilla',
+            'hadoop_version': '1.2.1',
             'node_processes': ['namenode']}
         self._assert_create_object_validation(
             data=data,
@@ -228,11 +183,11 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'test-ng',
                 'flavor_id': '1',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['namenode']
             },
-            bad_req_i=(1, 'NOT_FOUND',
+            bad_req_i=(1, 'INVALID_REFERENCE',
                        "Requested flavor '1' not found")
         )
 
@@ -241,12 +196,12 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'test-ng',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['namenode'],
                 'node_configs': {
                     'wrong_target': {
-                        u'mapreduce.task.tmp.dir': '/temp/'
+                        u'hadoop.tmp.dir': '/temp/'
                     }
                 }},
             bad_req_i=(1, 'INVALID_REFERENCE',
@@ -257,17 +212,17 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'test-ng',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['namenode'],
                 'node_configs': {
-                    'general': {
+                    'HDFS': {
                         's': 'a'
                     }
                 }
             },
             bad_req_i=(1, 'INVALID_REFERENCE',
-                       "Plugin's applicable target 'general' doesn't "
+                       "Plugin's applicable target 'HDFS' doesn't "
                        "contain config with name 's'")
         )
 
@@ -276,32 +231,32 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['wrong_process'],
                 'volumes_per_node': -1
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'-1(.0)? is less than the minimum of 0')
+                       u'-1.0 is less than the minimum of 0')
         )
         self._assert_create_object_validation(
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['wrong_process'],
                 'volumes_size': 0
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'0(.0)? is less than the minimum of 1')
+                       u'0.0 is less than the minimum of 1')
         )
         self._assert_create_object_validation(
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['datanode', 'tasktracker'],
                 'volumes_per_node': 1,
                 'volumes_size': 1,
@@ -311,8 +266,8 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
         data = {
             'name': 'a',
             'flavor_id': '42',
-            'plugin_name': 'fake',
-            'hadoop_version': '0.1',
+            'plugin_name': 'vanilla',
+            'hadoop_version': '1.2.1',
             'node_processes': ['datanode', 'tasktracker'],
             'volumes_per_node': 1,
             'volumes_size': 1,
@@ -328,25 +283,11 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
             data={
                 'name': 'a',
                 'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
                 'node_processes': ['datanode', 'tasktracker'],
                 'floating_ip_pool': 'network_bad'
             },
-            bad_req_i=(1, 'NOT_FOUND', "Floating IP pool network_bad "
-                                       "not found")
-        )
-
-    def test_volumes_per_node_without_volumes_size(self):
-        self._assert_create_object_validation(
-            data={
-                'name': 'a',
-                'flavor_id': '42',
-                'plugin_name': 'fake',
-                'hadoop_version': '0.1',
-                'node_processes': ['datanode', 'tasktracker'],
-                'volumes_per_node': 1
-            },
-            bad_req_i=(1, 'INVALID_REFERENCE', "You must specify a "
-                                               "volumes_size parameter")
+            bad_req_i=(1, 'INVALID_REFERENCE', "Floating IP pool network_bad "
+                                               "for node group 'a' not found")
         )
