@@ -16,12 +16,14 @@
 import xml.dom.minidom as xml
 
 import six
-import testtools
+import unittest2
+
+from sahara.utils import patches
 
 
-class MinidomPatchesTest(testtools.TestCase):
+class MinidomPatchesTest(unittest2.TestCase):
     def setUp(self):
-        super(MinidomPatchesTest, self).setUp()
+        patches.patch_minidom_writexml()
 
     def _generate_n_prettify_xml(self):
         doc = xml.Document()
@@ -46,7 +48,8 @@ class MinidomPatchesTest(testtools.TestCase):
         return doc.toprettyxml(indent="  ")
 
     def test_minidom_toprettyxml(self):
-        self.assertEqual("""<?xml version="1.0" ?>
+        self.assertEqual(self._generate_n_prettify_xml(),
+                         """<?xml version="1.0" ?>
 <?xml-smth type="text/smth" href="test.smth"?>
 <root>
   <element>
@@ -70,4 +73,4 @@ class MinidomPatchesTest(testtools.TestCase):
     <value>value-4</value>
   </element>
 </root>
-""", self._generate_n_prettify_xml())
+""")
