@@ -13,12 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import testtools
+import unittest2
 
-from sahara.utils import types
+from sahara.utils import types as types
 
 
-class TypesTestCase(testtools.TestCase):
+class TypesTestCase(unittest2.TestCase):
 
     def test_is_int(self):
         self.assertTrue(types.is_int('1'))
