@@ -15,14 +15,11 @@
 
 import hashlib
 
-from oslo_config import cfg
-from oslo_log import log
+from oslo.config import cfg
 
 from sahara import context
 from sahara import exceptions as ex
-from sahara.i18n import _
-from sahara.i18n import _LW
-from sahara.utils.openstack import base as b
+from sahara.openstack.common import log
 from sahara.utils.openstack import nova
 from sahara.utils import xmlutils as x
 
@@ -39,25 +36,31 @@ LOG = log.getLogger(__name__)
 opts = [
     cfg.BoolOpt('enable_data_locality',
                 default=False,
-                help="Enables data locality for hadoop cluster. "
-                     "Also enables data locality for Swift used by hadoop. "
-                     "If enabled, 'compute_topology' and 'swift_topology' "
-                     "configuration parameters should point to OpenStack and "
-                     "Swift topology correspondingly."),
+                help="""Enables data locality for hadoop cluster.
+                 Also enables data locality for Swift used by hadoop.
+                 If enabled, 'compute_topology' and 'swift_topology'
+                 configuration parameters should point to OpenStack and Swift
+                 topology correspondingly."""),
     cfg.BoolOpt('enable_hypervisor_awareness',
                 default=True,
-                help="Enables four-level topology for data locality. "
-                     "Works only if corresponding plugin supports such mode."),
+                help="""Enables four-level topology for data locality.
+                Works only if corresponding plugin supports such mode."""),
     cfg.StrOpt('compute_topology_file',
                default='etc/sahara/compute.topology',
-               help="File with nova compute topology. "
-                    "It should contain mapping between nova computes and "
-                    "racks."),
+               help="""File with nova compute topology.
+                It should contain mapping between nova computes and racks.
+                File format:
+                compute1 /rack1
+                compute2 /rack2
+                compute3 /rack2"""),
     cfg.StrOpt('swift_topology_file',
                default='etc/sahara/swift.topology',
-               help="File with Swift topology."
-                    "It should contain mapping between Swift nodes and "
-                    "racks.")
+               help="""File with Swift topology.
+                It should contain mapping between Swift nodes and racks.
+                File format:
+                node1 /rack1
+                node2 /rack2
+                node3 /rack2""")
 ]
 
 CONF = cfg.CONF
@@ -65,8 +68,6 @@ CONF.register_opts(opts)
 
 
 def _read_swift_topology():
-    LOG.debug("Reading Swift nodes topology from {config}".format(
-              config=CONF.swift_topology_file))
     topology = {}
     try:
         with open(CONF.swift_topology_file) as f:
@@ -77,16 +78,13 @@ def _read_swift_topology():
                 (host, path) = line.split()
                 topology[host] = path
     except IOError:
-        LOG.warning(_LW("Unable to read Swift nodes topology from {config}")
-                    .format(config=CONF.swift_topology_file))
-        return {}
-
+        raise ex.NotFoundException(
+            CONF.swift_topology_file,
+            "Unable to find file %s with Swift topology")
     return topology
 
 
 def _read_compute_topology():
-    LOG.debug("Reading compute nodes topology from {config}".format(
-              config=CONF.compute_topology_file))
     ctx = context.ctx()
     tenant_id = str(ctx.tenant_id)
     topology = {}
@@ -97,16 +95,16 @@ def _read_compute_topology():
                 if not line:
                     continue
                 (host, path) = line.split()
-                # Calculating host id based on tenant id and host
-                # using the same algorithm as in nova
-                # see nova/api/openstack/compute/views/servers.py
-                # def _get_host_id(instance):
+                #calulating host id based on tenant id and host
+                #using the same algorithm as in nova
+                #see nova/api/openstack/compute/views/servers.py
+                #def _get_host_id(instance):
                 sha_hash = hashlib.sha224(tenant_id + host)
                 topology[sha_hash.hexdigest()] = path
     except IOError:
         raise ex.NotFoundException(
             CONF.compute_topology_file,
-            _("Unable to find file %s with compute topology"))
+            "Unable to find file %s with compute topology")
     return topology
 
 
@@ -116,13 +114,13 @@ def generate_topology_map(cluster, is_node_awareness):
     topology_mapping = {}
     for ng in cluster.node_groups:
         for i in ng.instances:
-            # TODO(alazarev) get all servers info with one request
-            ni = b.execute_with_retries(nova_client.servers.get, i.instance_id)
+            #TODO(alazarev) get all servers info with one request
+            ni = nova_client.servers.get(i.instance_id)
             hostId = ni.hostId
             if hostId not in mapping:
                 raise ex.NotFoundException(
-                    i.instance_id,
-                    _("Was not able to find compute node topology for VM %s"))
+                    i.instance_id, "Was not able to find compute node "
+                                   "topology for VM %s")
             rack = mapping[hostId]
             if is_node_awareness:
                 rack += "/" + hostId
@@ -147,22 +145,18 @@ def vm_awareness_core_config():
         if param:
             param['value'] = 'org.apache.hadoop.net.NetworkTopology'
 
-    LOG.debug("Vm awareness will add following configs in core-site "
-              "params: {result}".format(result=result))
+    LOG.info("Vm awareness will add following configs in core-site "
+             "params: %s", result)
     return result
 
 
 def vm_awareness_mapred_config():
     c = x.load_hadoop_xml_defaults('topology/resources/mapred-template.xml')
     result = [cfg for cfg in c if cfg['value']]
-    LOG.debug("Vm awareness will add following configs in map-red "
-              "params: {result}".format(result=result))
+    LOG.info("Vm awareness will add following configs in map-red "
+             "params: %s", result)
     return result
 
 
 def vm_awareness_all_config():
     return vm_awareness_core_config() + vm_awareness_mapred_config()
-
-
-def is_data_locality_enabled():
-    return CONF.enable_data_locality
